@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern::Document::OpenAPI; # git description: v0.013-6-gbd6a34c
+package JSON::Schema::Modern::Document::OpenAPI; # git description: v0.014-4-g905a016
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One OpenAPI v3.1 document
 # KEYWORDS: JSON Schema data validation request response OpenAPI
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -174,8 +174,18 @@ sub _add_vocab_and_default_schemas ($self) {
   $js->add_vocabulary('JSON::Schema::Modern::Vocabulary::OpenAPI');
 
   $js->add_format_validation(
-    int32 => +{ type => 'integer', sub => sub ($x) { $x = Math::BigInt->new($x); my $bound = Math::BigInt->new(2) ** 31; $x >= -$bound && $x < $bound } },
-    int64 => +{ type => 'integer', sub => sub ($x) { $x = Math::BigInt->new($x); my $bound = Math::BigInt->new(2) ** 63; $x >= -$bound && $x < $bound } },
+    int32 => +{ type => 'integer', sub => sub ($x) {
+      require Math::BigInt;
+      $x = Math::BigInt->new($x);
+      my $bound = Math::BigInt->new(2) ** 31;
+      $x >= -$bound && $x < $bound;
+    } },
+    int64 => +{ type => 'integer', sub => sub ($x) {
+      require Math::BigInt;
+      $x = Math::BigInt->new($x);
+      my $bound = Math::BigInt->new(2) ** 63;
+      $x >= -$bound && $x < $bound;
+    } },
     float => +{ type => 'number', sub => sub ($) { 1 } },
     double => +{ type => 'number', sub => sub ($) { 1 } },
     password => +{ type => 'string', sub => sub ($) { 1 } },
@@ -220,7 +230,7 @@ JSON::Schema::Modern::Document::OpenAPI - One OpenAPI v3.1 document
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
